
import org.apache.commons.configuration.CompositeConfiguration;
import org.apache.commons.configuration.Configuration;
import org.apache.commons.configuration.ConfigurationException;
import org.apache.commons.configuration.ConfigurationFactory;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class AppConfigFactory extends CompositeConfiguration {

    private static Log log = LogFactory.getLog(AppConfigFactory.class);
    private static AppConfigFactory instance;
    private static String configFile = "config.xml";

    // Singleton initialiser
    static {
        instance = new AppConfigFactory(configFile);
    }

    /**
     * Constructor
     *
     * @param fileName Configuration file name.
     */
    private AppConfigFactory(String fileName) {
        init(fileName);
    }

    /**
     * Initialize the class.
     *
     * @param fileName Configuration file name.
     */
    private void init(String fileName) {
        try {
            ConfigurationFactory factory = new ConfigurationFactory(fileName);
            Configuration config = factory.getConfiguration();
            addConfiguration(config);
        } catch (ConfigurationException configEx) {
            log.error(configEx.getMessage());
            configEx.printStackTrace();
        }
    }

    /**
     * Singleton access method.
     *
     * @return Singleton
     */
    public static AppConfigFactory getInstance() {
        return instance;
    }
}
